@@ -45,7 +45,7 @@ struct _IndicEngineFc
 
 struct _PangoIndicInfo
 {
-  PangoOTTag               scriptTag; 
+  PangoOTTag               scriptTag;
   const IndicOTClassTable *classTable;
   const gchar             *gsubQuarkName;
   const gchar             *gposQuarkName;
@@ -139,15 +139,10 @@ maybe_add_GSUB_feature (PangoOTRuleset *ruleset,
 			gulong          property_bit)
 {
   guint feature_index;
-  
-  /* 0xffff == default language system */
-  if (pango_ot_info_find_feature (info, PANGO_OT_TABLE_GSUB,
-				  feature_tag, script_index, 0xffff, &feature_index))
-    {
-      /*
-      printf("Added GSUB feature '%c%c%c%c' = %8.8X\n", feature_tag>>24, feature_tag>>16&0xFF, feature_tag>>8&0xFF, feature_tag&0xFF, property_bit);
-      */
 
+  if (pango_ot_info_find_feature (info, PANGO_OT_TABLE_GSUB,
+				  feature_tag, script_index, PANGO_OT_DEFAULT_LANGUAGE, &feature_index))
+    {
       pango_ot_ruleset_add_feature (ruleset, PANGO_OT_TABLE_GSUB, feature_index,
 				    property_bit);
     }
@@ -155,7 +150,7 @@ maybe_add_GSUB_feature (PangoOTRuleset *ruleset,
 
 static void
 maybe_add_GPOS_feature (PangoOTRuleset *ruleset,
-		        PangoOTInfo    *info,
+			PangoOTInfo    *info,
 			guint           script_index,
 			PangoOTTag      feature_tag,
 			gulong          property_bit)
@@ -163,12 +158,8 @@ maybe_add_GPOS_feature (PangoOTRuleset *ruleset,
   guint feature_index;
 
   if (pango_ot_info_find_feature (info, PANGO_OT_TABLE_GPOS,
-				  feature_tag,script_index, 0xffff, &feature_index))
+				  feature_tag,script_index, PANGO_OT_DEFAULT_LANGUAGE, &feature_index))
     {
-      /*
-      printf("Added GPOS feature '%c%c%c%c' = %8.8X\n", feature_tag>>24, feature_tag>>16&0xFF, feature_tag>>8&0xFF, feature_tag&0xFF, property_bit);
-      */
-
       pango_ot_ruleset_add_feature (ruleset, PANGO_OT_TABLE_GPOS, feature_index,
 				    property_bit);
     }
@@ -274,7 +265,7 @@ set_glyphs (PangoFont      *font,
 	  (!process_zwj || wcs[i] != 0x200D))
 	glyph = PANGO_GLYPH_EMPTY;
       else
-        {
+	{
 	  glyph = pango_fc_font_get_glyph (fc_font, wcs[i]);
 
 	  if (!glyph)
@@ -316,7 +307,7 @@ expand_text(const gchar *text, glong length, glong **offsets, glong *n_chars)
 
 
 /* analysis->shape_engine has the PangoEngine... */
-static void 
+static void
 indic_engine_shape (PangoEngineShape *engine,
 		    PangoFont        *font,
 		    const char       *text,
@@ -352,15 +343,15 @@ indic_engine_shape (PangoEngineShape *engine,
   indic_info = indic_shape_engine->indicInfo;
 
   wc_in    = expand_text (text, length, &utf8_offsets, &n_chars);
- 
+
   n_glyphs = indic_ot_reorder (wc_in, utf8_offsets, n_chars, indic_info->classTable, NULL, NULL, NULL, NULL);
-  
+
   wc_out  = g_new (gunichar, n_glyphs);
   indices = g_new (glong,    n_glyphs);
   tags    = g_new (gulong,   n_glyphs);
 
   n_glyphs  = indic_ot_reorder (wc_in, utf8_offsets, n_chars, indic_info->classTable, wc_out, indices, tags, &mprefixups);
-  
+
   pango_glyph_string_set_size (glyphs, n_glyphs);
   buffer = pango_ot_buffer_new (fc_font);
 
@@ -407,20 +398,20 @@ indic_engine_fc_class_init (PangoEngineShapeClass *class)
 }
 
 PANGO_ENGINE_SHAPE_DEFINE_TYPE (IndicEngineFc, indic_engine_fc,
-				indic_engine_fc_class_init, NULL);
+				indic_engine_fc_class_init, NULL)
 
-void 
+void
 PANGO_MODULE_ENTRY(init) (GTypeModule *module)
 {
   indic_engine_fc_register_type (module);
 }
 
-void 
+void
 PANGO_MODULE_ENTRY(exit) (void)
 {
 }
 
-void 
+void
 PANGO_MODULE_ENTRY(list) (PangoEngineInfo **engines,
 			  int              *n_engines)
 {
@@ -439,7 +430,7 @@ PANGO_MODULE_ENTRY(create) (const char *id)
 	{
 	  IndicEngineFc *engine = g_object_new (indic_engine_fc_type, NULL);
 	  engine->indicInfo = &indic_info[i];
-					      
+
 	  return (PangoEngine *)engine;
 	}
     }
